# Python3 implementation of SATL

SATL stands for 'Simple APDU Transport Layer'. It is a simple way to exchange ISO7816-4 APDUs over interfaces not covered in ISO7816-3.

More info here: https://github.com/sebastien-riou/SATL
